==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-session/lxqt-session_ro_RO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro_RO">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <source>Application &apos;%1&apos; crashed too many times. Its autorestart has been disabled for current session.</source>
        <translation type="vanished">Aplicația &apos;%1&apos; a eșuat de prea multe ori. Repornirea automată a acestei aplicații a fost dezactivată pentru sesiunea curentă.</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="302"/>
        <source>Crash Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="303"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Bine ați venit în LXQt</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation type="vanished">&lt;b&gt;Bine ați venit în LXQt&lt;/b&gt;
&lt;p&gt;
Înainte de a utiliza LXQt, selectați un administrator de ferestre:</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>Altele...</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>Alegeți favoritul dvs.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-session/lxqt-session/lxqt-session_ro_RO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro_RO">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <source>Application &apos;%1&apos; crashed too many times. Its autorestart has been disabled for current session.</source>
        <translation type="vanished">Aplicația &apos;%1&apos; a eșuat de prea multe ori. Repornirea automată a acestei aplicații a fost dezactivată pentru sesiunea curentă.</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="309"/>
        <source>Crash Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="310"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <source>Configuration file path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>Window manager to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Bine ați venit în LXQt</translation>
    </message>
    <message>
        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
&lt;p&gt;
Before starting to use the LXQt, you might want to select the Windows Manager:</source>
        <translation type="vanished">&lt;b&gt;Bine ați venit în LXQt&lt;/b&gt;
&lt;p&gt;
Înainte de a utiliza LXQt, selectați un administrator de ferestre:</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>Altele...</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>Alegeți favoritul dvs.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
